@@ -606,6 +606,18 @@ class KrakenZ3(KrakenX3):
                 "lcd_resolution": (640, 640),
             },
         ),
+        (
+            0x1E71,
+            0x3014,
+            "NZXT Kraken 2024 Plus",
+            {
+                "speed_channels": _SPEED_CHANNELS_KRAKEN2023,
+                "color_channels": _COLOR_CHANNELS_KRAKEN2023,
+                "hwmon_ctrl_mapping": _HWMON_CTRL_MAPPING_KRAKENZ,
+                "bulk_buffer_size": 1024 * 1024 * 2,  # 2 MB
+                "lcd_resolution": (240, 240),
+            },
+        ),
     ]
 
     def __init__(
